@@ -1,6 +1,4 @@
-from django.conf.urls.defaults import *
-
-from django.views.generic.simple import direct_to_template
+from django.conf.urls import url, patterns
 
 
 urlpatterns = patterns("",
